@@ -3,28 +3,33 @@ import re
 
 from typing import TYPE_CHECKING, Any, Callable, Dict, Hashable, List, Optional
 
+from .typing import SeedType
+
 if TYPE_CHECKING:
     from .providers import BaseProvider
 
-_re_token = re.compile(r'\{\{\s*(\w+)(:\s*\w+?)?\s*\}\}')
+_re_token = re.compile(r"\{\{\s*(\w+)(:\s*\w+?)?\s*\}\}")
 random = random_module.Random()
 mod_random = random  # compat with name released in 0.8
 
 
-class Generator:
+Sentinel = object()
 
+
+class Generator:
     __config: Dict[str, Dict[Hashable, Any]] = {
-        'arguments': {},
+        "arguments": {},
     }
 
+    _is_seeded = False
+    _global_seed = Sentinel
+
     def __init__(self, **config: Dict) -> None:
         self.providers: List["BaseProvider"] = []
-        self.__config = dict(
-            list(self.__config.items()) + list(config.items()))
+        self.__config = dict(list(self.__config.items()) + list(config.items()))
         self.__random = random
 
     def add_provider(self, provider: "BaseProvider") -> None:
-
         if isinstance(provider, type):
             provider = provider(self)
 
@@ -32,7 +37,7 @@ class Generator:
 
         for method_name in dir(provider):
             # skip 'private' method
-            if method_name.startswith('_'):
+            if method_name.startswith("_"):
                 continue
 
             faker_function = getattr(provider, method_name)
@@ -43,8 +48,7 @@ class Generator:
 
     def provider(self, name: str) -> Optional["BaseProvider"]:
         try:
-            lst = [p for p in self.get_providers()
-                   if hasattr(p, '__provider__') and p.__provider__ == name.lower()]
+            lst = [p for p in self.get_providers() if hasattr(p, "__provider__") and p.__provider__ == name.lower()]
             return lst[0]
         except IndexError:
             return None
@@ -61,18 +65,21 @@ class Generator:
     def random(self, value: random_module.Random) -> None:
         self.__random = value
 
-    def seed_instance(self, seed: Optional[Hashable] = None) -> "Generator":
+    def seed_instance(self, seed: Optional[SeedType] = None) -> "Generator":
         """Calls random.seed"""
         if self.__random == random:
             # create per-instance random obj when first time seed_instance() is
             # called
             self.__random = random_module.Random()
         self.__random.seed(seed)
+        self._is_seeded = True
         return self
 
     @classmethod
-    def seed(cls, seed: Optional[Hashable] = None) -> None:
+    def seed(cls, seed: Optional[SeedType] = None) -> None:
         random.seed(seed)
+        cls._global_seed = seed
+        cls._is_seeded = True
 
     def format(self, formatter: str, *args: Any, **kwargs: Any) -> str:
         """
@@ -84,10 +91,10 @@ class Generator:
         try:
             return getattr(self, formatter)
         except AttributeError:
-            if 'locale' in self.__config:
+            if "locale" in self.__config:
                 msg = f'Unknown formatter {formatter!r} with locale {self.__config["locale"]!r}'
             else:
-                raise AttributeError(f'Unknown formatter {formatter!r}')
+                raise AttributeError(f"Unknown formatter {formatter!r}")
             raise AttributeError(msg)
 
     def set_formatter(self, name: str, method: Callable) -> None:
@@ -107,15 +114,15 @@ class Generator:
         generator.set_arguments('small', 'max_value', 10)
         generator.set_arguments('small', {'min_value': 5, 'max_value': 10})
         """
-        if group not in self.__config['arguments']:
-            self.__config['arguments'][group] = {}
+        if group not in self.__config["arguments"]:
+            self.__config["arguments"][group] = {}
 
         if isinstance(argument, dict):
-            self.__config['arguments'][group] = argument
+            self.__config["arguments"][group] = argument
         elif not isinstance(argument, str):
             raise ValueError("Arguments must be either a string or dictionary")
         else:
-            self.__config['arguments'][group][argument] = value
+            self.__config["arguments"][group][argument] = value
 
     def get_arguments(self, group: str, argument: Optional[str] = None) -> Any:
         """
@@ -126,10 +133,10 @@ class Generator:
         generator.get_arguments('small', 'max_value')
         generator.get_arguments('small')
         """
-        if group in self.__config['arguments'] and argument:
-            result = self.__config['arguments'][group].get(argument)
+        if group in self.__config["arguments"] and argument:
+            result = self.__config["arguments"][group].get(argument)
         else:
-            result = self.__config['arguments'].get(group)
+            result = self.__config["arguments"].get(group)
 
         return result
 
@@ -141,11 +148,11 @@ class Generator:
         generator.del_arguments('small')
         generator.del_arguments('small', 'max_value')
         """
-        if group in self.__config['arguments']:
+        if group in self.__config["arguments"]:
             if argument:
-                result = self.__config['arguments'][group].pop(argument)
+                result = self.__config["arguments"][group].pop(argument)
             else:
-                result = self.__config['arguments'].pop(group)
+                result = self.__config["arguments"].pop(group)
         else:
             result = None
 
@@ -169,16 +176,16 @@ class Generator:
 
     def __format_token(self, matches):
         formatter, argument_group = list(matches.groups())
-        argument_group = argument_group.lstrip(":").strip() if argument_group else ''
+        argument_group = argument_group.lstrip(":").strip() if argument_group else ""
 
         if argument_group:
             try:
-                arguments = self.__config['arguments'][argument_group]
+                arguments = self.__config["arguments"][argument_group]
             except KeyError:
-                raise AttributeError(f'Unknown argument group {argument_group!r}')
+                raise AttributeError(f"Unknown argument group {argument_group!r}")
 
             formatted = str(self.format(formatter, **arguments))
         else:
             formatted = str(self.format(formatter))
 
-        return ''.join(formatted)
+        return "".join(formatted)
