@@ -613,7 +613,6 @@ class Provider(AddressProvider):
         "Маврикій",
         "Мавританія",
         "Мадагаскар",
-        "Республіка Македонія",
         "Малаві",
         "Малайзія",
         "Малі",
@@ -651,6 +650,7 @@ class Provider(AddressProvider):
         "Південний Судан",
         "Польща",
         "Португалія",
+        "Респу́бліка Півні́чна Македо́нія",
         "Росія",
         "Руанда",
         "Румунія",
